==> estateplat-common-1.2.4-20210923.092626-889-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/KttZdjbxxNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.*;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 宗地基本信息
 * Created by xhc on 2015/11/19.
 */
@XmlRootElement(name = "KTT_ZDJBXX")
public class KttZdjbxxNew implements Serializable, AccessData {

    final static String ysdm = "6001010000";//要素代码
    private Integer bsm;//标识码
    private String zddm;//宗地代码
    private String bdcdyh;//不动产单元号
    private String zdtzm;//宗地特征码
    private String zl;//坐落
    private Double zdmj;//宗地面积
    private String mjdw;//面积单位
    private String yt;//用途
    private String dj;//等级
    private Double jg;//价格
    private String qllx;//权利类型
    private String qlxz;//权利性质
    private String qlsdfs;//权利设定方式
    private Double rjl;//容积率
    private Double jzmd;//建筑密度
    private Double jzxg;//建筑限高
    private String zdszd;//宗地四至-东
    private String zdszn;//宗地四至-南
    private String zdszx;//宗地四至-西
    private String zdszb;//宗地四至-北
    private String zdt;//宗地图
    private String tfh;//图幅号
    private String djh;//地籍号
    private String dah;//档案号
    private String bz;//备注
    private String zt;//状态
    private String qxdm;//区县代码
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private String djjgbm;//登记机构编码
    private String djjgmc;//登记机构名称
    private String jdh;//街道(乡、镇)
    private String jfh;//街坊（村）
    private String zh;//组

    private String id;
    private String zdtzmmc;
    private String mjdwmc;
    private String ytmc;
    private String djmc;
    private String qllxmc;
    private String qlxzmc;
    private String qlsdfsmc;
    private String ztmc;
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private String ghytmc;//用途名称
    private String ydyhfl;//用地用海分类
    private String jgdw;//价格单位
    private String dkdm;//地块代码

    @XmlAttribute(name = "GHYTMC")
    public String getGhytmc() {
        return ghytmc;
    }

    public void setGhytmc(String ghytmc) {
        this.ghytmc = ghytmc;
    }
    @XmlAttribute(name = "YDYHFL")
    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }
    @XmlAttribute(name = "JGDW")
    public String getJgdw() {
        return jgdw;
    }

    public void setJgdw(String jgdw) {
        this.jgdw = jgdw;
    }
    @XmlAttribute(name = "DKDM")
    public String getDkdm() {
        return dkdm;
    }

    public void setDkdm(String dkdm) {
        this.dkdm = dkdm;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "JDH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getJdh() {
        return jdh;
    }

    public void setJdh(String jdh) {
        this.jdh = jdh;
    }

    @XmlAttribute(name = "JFH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getJfh() {
        return jfh;
    }

    public void setJfh(String jfh) {
        this.jfh = jfh;
    }

    @XmlAttribute(name = "ZH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    @XmlAttribute(name = "BSM")
    public Integer getBsm() {
        return bsm;
    }

    public void setBsm(Integer bsm) {
        this.bsm = bsm;
    }

    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "ZDDM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZddm() {
        return zddm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    @XmlAttribute(name = "BDCDYH")
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    @XmlAttribute(name = "ZDTZM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZdtzm() {
        return zdtzm;
    }

    public void setZdtzm(String zdtzm) {
        this.zdtzm = zdtzm;
    }

    @XmlAttribute(name = "ZL")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    @XmlAttribute(name = "ZDMJ")
    @XmlJavaTypeAdapter(JaxbDoubleFourAdapter.class)
    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    @XmlAttribute(name = "MJDW")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    @XmlAttribute(name = "YT")
    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    @XmlAttribute(name = "DJ")
    public String getDj() {
        return dj;
    }

    public void setDj(String dj) {
        this.dj = dj;
    }

    @XmlAttribute(name = "JG")
    @XmlJavaTypeAdapter(JaxbDoubleFourAdapter.class)
    public Double getJg() {
        return jg;
    }

    public void setJg(Double jg) {
        this.jg = jg;
    }

    @XmlAttribute(name = "QLLX")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    @XmlAttribute(name = "QLXZ")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    @XmlAttribute(name = "QLSDFS")
    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    @XmlAttribute(name = "RJL")
    public Double getRjl() {
        return rjl;
    }

    public void setRjl(Double rjl) {
        this.rjl = rjl;
    }

    @XmlAttribute(name = "JZMD")
    @XmlJavaTypeAdapter(JaxbDoubleTwoAdapter.class)
    public Double getJzmd() {
        return jzmd;
    }

    public void setJzmd(Double jzmd) {
        this.jzmd = jzmd;
    }

    @XmlAttribute(name = "JZXG")
    @XmlJavaTypeAdapter(JaxbDoubleTwoAdapter.class)
    public Double getJzxg() {
        return jzxg;
    }

    public void setJzxg(Double jzxg) {
        this.jzxg = jzxg;
    }

    @XmlAttribute(name = "ZDSZD")
    @XmlJavaTypeAdapter(JaxbStringOver200.class)
    public String getZdszd() {
        return zdszd;
    }

    public void setZdszd(String zdszd) {
        this.zdszd = zdszd;
    }

    @XmlAttribute(name = "ZDSZN")
    @XmlJavaTypeAdapter(JaxbStringOver200.class)
    public String getZdszn() {
        return zdszn;
    }

    public void setZdszn(String zdszn) {
        this.zdszn = zdszn;
    }

    @XmlAttribute(name = "ZDSZX")
    @XmlJavaTypeAdapter(JaxbStringOver200.class)
    public String getZdszx() {
        return zdszx;
    }

    public void setZdszx(String zdszx) {
        this.zdszx = zdszx;
    }

    @XmlAttribute(name = "ZDSZB")
    @XmlJavaTypeAdapter(JaxbStringOver200.class)
    public String getZdszb() {
        return zdszb;
    }

    public void setZdszb(String zdszb) {
        this.zdszb = zdszb;
    }

    @XmlAttribute(name = "ZDT")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZdt() {
        return zdt;
    }

    public void setZdt(String zdt) {
        this.zdt = zdt;
    }

    @XmlAttribute(name = "TFH")
    public String getTfh() {
        return tfh;
    }

    public void setTfh(String tfh) {
        this.tfh = tfh;
    }

    @XmlAttribute(name = "DJH")
    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    @XmlAttribute(name = "DAH")
    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    @XmlAttribute(name = "BZ")
    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    @XmlAttribute(name = "ZT")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    @XmlAttribute(name = "DJSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    @XmlAttribute(name = "DBR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    @XmlAttribute(name = "FJ")
    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    @XmlAttribute(name = "DJJGBM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjjgbm() {
        return djjgbm;
    }

    public void setDjjgbm(String djjgbm) {
        this.djjgbm = djjgbm;
    }

    @XmlAttribute(name = "DJJGMC")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjjgmc() {
        return djjgmc;
    }

    public void setDjjgmc(String djjgmc) {
        this.djjgmc = djjgmc;
    }

    public String getZtmc() {
        return ztmc;
    }

    public void setZtmc(String ztmc) {
        this.ztmc = ztmc;
    }
    @XmlTransient
    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }
    @XmlTransient
    public String getZdtzmmc() {
        return zdtzmmc;
    }

    public void setZdtzmmc(String zdtzmmc) {
        this.zdtzmmc = zdtzmmc;
    }
    @XmlTransient
    public String getMjdwmc() {
        return mjdwmc;
    }

    public void setMjdwmc(String mjdwmc) {
        this.mjdwmc = mjdwmc;
    }
    @XmlTransient
    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }
    @XmlTransient
    public String getDjmc() {
        return djmc;
    }

    public void setDjmc(String djmc) {
        this.djmc = djmc;
    }
    @XmlTransient
    public String getQllxmc() {
        return qllxmc;
    }

    public void setQllxmc(String qllxmc) {
        this.qllxmc = qllxmc;
    }
    @XmlTransient
    public String getQlxzmc() {
        return qlxzmc;
    }

    public void setQlxzmc(String qlxzmc) {
        this.qlxzmc = qlxzmc;
    }
    @XmlTransient
    public String getQlsdfsmc() {
        return qlsdfsmc;
    }

    public void setQlsdfsmc(String qlsdfsmc) {
        this.qlsdfsmc = qlsdfsmc;
    }
}

==> estateplat-common-1.2.4-20220621.084244-1048-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/KttZdjbxxNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.*;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 宗地基本信息
 * Created by xhc on 2015/11/19.
 */
@XmlRootElement(name = "KTT_ZDJBXX")
@Table(name = "KTT_ZDJBXX")
public class KttZdjbxxNew implements Serializable, AccessData {

    final static String ysdm = "6001010000";//要素代码
    private Integer bsm;//标识码
    private String zddm;//宗地代码
    private String bdcdyh;//不动产单元号
    private String zdtzm;//宗地特征码
    private String zl;//坐落
    private Double zdmj;//宗地面积
    private String mjdw;//面积单位
    private String yt;//用途
    private String dj;//等级
    private Double jg;//价格
    private String qllx;//权利类型
    private String qlxz;//权利性质
    private String qlsdfs;//权利设定方式
    private Double rjl;//容积率
    private Double jzmd;//建筑密度
    private Double jzxg;//建筑限高
    private String zdszd;//宗地四至-东
    private String zdszn;//宗地四至-南
    private String zdszx;//宗地四至-西
    private String zdszb;//宗地四至-北
    private String zdt;//宗地图
    private String tfh;//图幅号
    private String djh;//地籍号
    private String dah;//档案号
    private String bz;//备注
    private String zt;//状态
    private String qxdm;//区县代码
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private String djjgbm;//登记机构编码
    private String djjgmc;//登记机构名称
    private String jdh;//街道(乡、镇)
    private String jfh;//街坊（村）
    private String zh;//组

    private String id;
    private String zdtzmmc;
    private String mjdwmc;
    private String ytmc;
    private String djmc;
    private String qllxmc;
    private String qlxzmc;
    private String qlsdfsmc;
    private String ztmc;
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private String ghytmc;//用途名称
    private String ydyhfl;//用地用海分类
    private String jgdw;//价格单位
    private String dkdm;//地块代码

    @XmlAttribute(name = "GHYTMC")
    public String getGhytmc() {
        return ghytmc;
    }

    public void setGhytmc(String ghytmc) {
        this.ghytmc = ghytmc;
    }
    @XmlAttribute(name = "YDYHFL")
    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }
    @XmlAttribute(name = "JGDW")
    public String getJgdw() {
        return jgdw;
    }

    public void setJgdw(String jgdw) {
        this.jgdw = jgdw;
    }
    @XmlAttribute(name = "DKDM")
    public String getDkdm() {
        return dkdm;
    }

    public void setDkdm(String dkdm) {
        this.dkdm = dkdm;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "JDH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getJdh() {
        return jdh;
    }

    public void setJdh(String jdh) {
        this.jdh = jdh;
    }

    @XmlAttribute(name = "JFH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getJfh() {
        return jfh;
    }

    public void setJfh(String jfh) {
        this.jfh = jfh;
    }

    @XmlAttribute(name = "ZH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    @XmlAttribute(name = "BSM")
    @XmlJavaTypeAdapter(JaxbNotNullIntegerAdapter.class)
    public Integer getBsm() {
        return bsm;
    }

    public void setBsm(Integer bsm) {
        this.bsm = bsm;
    }

    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "ZDDM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZddm() {
        return zddm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    @XmlAttribute(name = "BDCDYH")
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    @XmlAttribute(name = "ZDTZM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZdtzm() {
        return zdtzm;
    }

    public void setZdtzm(String zdtzm) {
        this.zdtzm = zdtzm;
    }

    @XmlAttribute(name = "ZL")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    @XmlAttribute(name = "ZDMJ")
    @XmlJavaTypeAdapter(JaxbNotNullDoubleFourAdapter.class)
    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    @XmlAttribute(name = "MJDW")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    @XmlAttribute(name = "YT")
    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    @XmlAttribute(name = "DJ")
    public String getDj() {
        return dj;
    }

    public void setDj(String dj) {
        this.dj = dj;
    }

    @XmlAttribute(name = "JG")
    @XmlJavaTypeAdapter(JaxbNotNullDoubleFourAdapter.class)
    public Double getJg() {
        return jg;
    }

    public void setJg(Double jg) {
        this.jg = jg;
    }

    @XmlAttribute(name = "QLLX")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    @XmlAttribute(name = "QLXZ")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    @XmlAttribute(name = "QLSDFS")
    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    @XmlAttribute(name = "RJL")
    @XmlJavaTypeAdapter(JaxbNotNullDoubleTwoAdapter.class)
    public Double getRjl() {
        return rjl;
    }

    public void setRjl(Double rjl) {
        this.rjl = rjl;
    }

    @XmlAttribute(name = "JZMD")
    @XmlJavaTypeAdapter(JaxbNotNullDoubleTwoAdapter.class)
    public Double getJzmd() {
        return jzmd;
    }

    public void setJzmd(Double jzmd) {
        this.jzmd = jzmd;
    }

    @XmlAttribute(name = "JZXG")
    @XmlJavaTypeAdapter(JaxbNotNullDoubleTwoAdapter.class)
    public Double getJzxg() {
        return jzxg;
    }

    public void setJzxg(Double jzxg) {
        this.jzxg = jzxg;
    }

    @XmlAttribute(name = "ZDSZD")
    @XmlJavaTypeAdapter(JaxbStringOver200.class)
    public String getZdszd() {
        return zdszd;
    }

    public void setZdszd(String zdszd) {
        this.zdszd = zdszd;
    }

    @XmlAttribute(name = "ZDSZN")
    @XmlJavaTypeAdapter(JaxbStringOver200.class)
    public String getZdszn() {
        return zdszn;
    }

    public void setZdszn(String zdszn) {
        this.zdszn = zdszn;
    }

    @XmlAttribute(name = "ZDSZX")
    @XmlJavaTypeAdapter(JaxbStringOver200.class)
    public String getZdszx() {
        return zdszx;
    }

    public void setZdszx(String zdszx) {
        this.zdszx = zdszx;
    }

    @XmlAttribute(name = "ZDSZB")
    @XmlJavaTypeAdapter(JaxbStringOver200.class)
    public String getZdszb() {
        return zdszb;
    }

    public void setZdszb(String zdszb) {
        this.zdszb = zdszb;
    }

    @XmlAttribute(name = "ZDT")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZdt() {
        return zdt;
    }

    public void setZdt(String zdt) {
        this.zdt = zdt;
    }

    @XmlAttribute(name = "TFH")
    public String getTfh() {
        return tfh;
    }

    public void setTfh(String tfh) {
        this.tfh = tfh;
    }

    @XmlAttribute(name = "DJH")
    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    @XmlAttribute(name = "DAH")
    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    @XmlAttribute(name = "BZ")
    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    @XmlAttribute(name = "ZT")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    @XmlAttribute(name = "DJSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    @XmlAttribute(name = "DBR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    @XmlAttribute(name = "FJ")
    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    @XmlAttribute(name = "DJJGBM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjjgbm() {
        return djjgbm;
    }

    public void setDjjgbm(String djjgbm) {
        this.djjgbm = djjgbm;
    }

    @XmlAttribute(name = "DJJGMC")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjjgmc() {
        return djjgmc;
    }

    public void setDjjgmc(String djjgmc) {
        this.djjgmc = djjgmc;
    }

    public String getZtmc() {
        return ztmc;
    }

    public void setZtmc(String ztmc) {
        this.ztmc = ztmc;
    }
    @XmlTransient
    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }
    @XmlTransient
    public String getZdtzmmc() {
        return zdtzmmc;
    }

    public void setZdtzmmc(String zdtzmmc) {
        this.zdtzmmc = zdtzmmc;
    }
    @XmlTransient
    public String getMjdwmc() {
        return mjdwmc;
    }

    public void setMjdwmc(String mjdwmc) {
        this.mjdwmc = mjdwmc;
    }
    @XmlTransient
    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }
    @XmlTransient
    public String getDjmc() {
        return djmc;
    }

    public void setDjmc(String djmc) {
        this.djmc = djmc;
    }
    @XmlTransient
    public String getQllxmc() {
        return qllxmc;
    }

    public void setQllxmc(String qllxmc) {
        this.qllxmc = qllxmc;
    }
    @XmlTransient
    public String getQlxzmc() {
        return qlxzmc;
    }

    public void setQlxzmc(String qlxzmc) {
        this.qlxzmc = qlxzmc;
    }
    @XmlTransient
    public String getQlsdfsmc() {
        return qlsdfsmc;
    }

    public void setQlsdfsmc(String qlsdfsmc) {
        this.qlsdfsmc = qlsdfsmc;
    }
}
